<?php
/**
 * @file
 * Administrative page callbacks for the SharpSpring module.
 */

/**
 * Implements hook_form().
 */
function sharpspring_admin_config_form($form_state) {
  $form['account'] = array(
    '#type' => 'fieldset',
    '#title' => t('Tracking Settings'),
  );

  $form['account']['sharpspring_account'] = array(
    '#title' => t('Web Property ID'),
    '#type' => 'textfield',
    '#default_value' => variable_get('sharpspring_account', 'KOI-'),
    '#size' => 15,
    '#maxlength' => 20,
    '#required' => TRUE,
    '#description' => t("This ID is unique to each site you want to track separately, and is in the form of KOI-xxxxxxx. It is defined in the tracking code as '_setAccount'."),
  );

  $form['account']['sharpspring_domain'] = array(
    '#title' => t('Web Property Domain'),
    '#type' => 'textfield',
    '#default_value' => variable_get('sharpspring_domain', 'koi-000000.marketingautomation.com'),
    '#size' => 60,
    '#maxlength' => 60,
    '#required' => TRUE,
    '#description' => t("This is the SharpSpring sub-domain to which tracking information is sent. It is defined in the tracking code as '_setDomain'. Omit the protocol and path: it should fit the following format: koi-xxxxxx.marketingautomation.services"),
  );

  $form['account']['finding_values'] = array(
    '#markup' => t('For more information on how to find and set these values please see <a href="http://help.sharpspring.com/customer/portal/articles/1497453-how-to-insert-sharpspring-tracking-code-how-to-add-additional-sites" target="_blank">http://help.sharpspring.com/customer/portal/articles/1497453-how-to-insert-sharpspring-tracking-code-how-to-add-additional-sites</a>'),
  );

  $form['api'] = array(
    '#type' => 'fieldset',
    '#title' => t('API Settings'),
    '#description' => t('For advanced integrations, input your Account ID and Secret Key from the !url', array('!url' => l('SharpSpring Public API', 'https://app.sharpspring.com/settings/pubapi', array('target' => '_blank')))),
  );

  $form['api']['sharpspring_api_account_id'] = array(
    '#title' => t('Account ID'),
    '#type' => 'textfield',
    '#default_value' => variable_get('sharpspring_api_account_id', ''),
    '#size' => 40,
    '#maxlength' => 40,
  );

  $form['api']['sharpspring_api_secret_key'] = array(
    '#title' => t('Secret Key'),
    '#type' => 'textfield',
    '#default_value' => variable_get('sharpspring_api_secret_key', ''),
    '#size' => 40,
    '#maxlength' => 40,
  );

  return system_settings_form($form);
}

/**
 * Implements hook_form_validate().
 */
function sharpspring_admin_config_form_validate($form, &$form_state) {

  // Trim some text values.
  $form_state['values']['sharpspring_account'] = trim($form_state['values']['sharpspring_account']);
  $form_state['values']['sharpspring_domain'] = trim($form_state['values']['sharpspring_domain']);
  $form_state['values']['sharpspring_api_account_id'] = trim($form_state['values']['sharpspring_api_account_id']);
  $form_state['values']['sharpspring_api_secret_key'] = trim($form_state['values']['sharpspring_api_secret_key']);

  // Replace all type of dashes (n-dash, m-dash, minus) with the normal dashes.
  $form_state['values']['sharpspring_account'] = str_replace(array(
    '–', '—', '−',
  ), '-', $form_state['values']['sharpspring_account']);

  if (!_sharpspring_validate_id($form_state['values']['sharpspring_account'])) {
    form_set_error('sharpspring_account', t('A valid SharpSpring Web Property ID is case sensitive and formatted like KOI-xxxxxxx.'));
  }

  if (!_sharpspring_validate_domain($form_state['values']['sharpspring_domain'])) {
    form_set_error('sharpspring_domain', t('A valid SharpSpring Domain is formatted like koi-XXXXXX.sharpspring.com. Try removing the leading protocol (e.g. https://) or trailing path. (e.g. /somepath).'));
  }

}
